@@ -6,7 +6,9 @@ emoticons = {
 ';o)': 'Wink.png',
 ';-)': 'Wink.png',
 ':(': 'Sad.png',
+':-(': 'Sad.png',
 ':/': 'Erf.png',
+':-/': 'Erf.png',
 ':p': 'Tongue.png',
 ':P': 'Tongue.png',
 ':o': 'O.png',
@@ -41,11 +43,10 @@ emoticons = {
 ':vomi:': 'Vomi.gif',
 ':drapal:': 'Drapal.png',
 ':+1:': '+1.png',
+':ban:': 'Ban.png',
 ':boulay:': 'Boulay.png',
 ':thalis:': 'Thalis.png',
 ':afrojojo:': 'Afrojojo.png',
-':aloy:': 'Aloy.png',
-':ban:': 'Ban.png',
 ':pouah:': 'Pouah.png',
 ':nico54:': 'Nico54.png',
 ':yvele:': 'Yvele.png',
@@ -54,7 +55,6 @@ emoticons = {
 ':x': 'Shut.png',
 ':neriki:': 'Neriki.png',
 ':cry:': 'Cry.gif',
-':lol:': 'Lol.gif',
 ':whistle:': 'Whistle.gif',
 ':heink:': 'Heink.gif',
 ':jap:': 'Jap.gif',
@@ -79,7 +79,6 @@ emoticons = {
 ':totoz:': 'Totoz.gif',
 ':prodigy:': 'Prodigy.png',
 ':makokotte:': 'Makokotte.gif',
-':rofl:': 'Rofl.gif',
 ':simchevelu:': 'Simchevelu.gif',
 ':bernadette:': 'Bernadette.png',
 ':sisicaivrai:': 'Sisicaivrai.gif',
@@ -90,4 +89,10 @@ emoticons = {
 ':atsuko:': 'Atsuko.gif',
 ':zeusy:' : 'Zeusy.png',
 ':dawacube:' : 'Dawacube.gif',
+':lol:': 'Lol.gif',
+':rofl:': 'Rofl.gif',
+':toad666:' : 'Toad666.gif',
+':sarcastic:': 'Sarcastic.gif',
+':aloy:': 'Aloy.png',
+':debarquement:': 'Debarquement.png',
 }
